erase_file_cache: Delete the full package cache directory for the given...

View source: R/filecache.R

erase_file_cacheR Documentation

Delete the full package cache directory for the given package.

Description

Delete the full package cache directory for the given package.

Usage

erase_file_cache(pkg_info)

Arguments

pkg_info

named list. Package identifier, see get_pkg_info() on how to get one.

Value

integer. The return value of the unlink() call: 0 for success, 1 for failure. See the unlink() documentation for details.


pkgfilecache documentation built on Sept. 1, 2026, 1:08 a.m.