get_abs_filenames: Join all relative filenames to a datadir.

View source: R/filecache.R

get_abs_filenamesR Documentation

Join all relative filenames to a datadir.

Description

For each file, create a full path by joining the datadir with the filename.

Usage

get_abs_filenames(datadir, relative_filenames)

Arguments

datadir

string, the path to the package cache directory.

relative_filenames

vector of strings. A vector of filenames, relative to the package cache. Can be a list of vectors, which will be interpreted as files with subdirs.

Value

vector of strings, the absolute file names.


pkgfilecache documentation built on Sept. 1, 2026, 1:08 a.m.