make_pgk_cache_subdir_for_all_relative_files: Given a relative file, create the subdir in the package cache...

View source: R/filecache.R

make_pgk_cache_subdir_for_all_relative_filesR Documentation

Given a relative file, create the subdir in the package cache if needed.

Description

Given a relative file, create the subdir in the package cache if needed.

Usage

make_pgk_cache_subdir_for_all_relative_files(pkg_info, relative_filenames)

Arguments

pkg_info

named list. Package identifier, see get_pkg_info() on how to get one.

relative_filenames

vector of strings. A vector of filenames, relative to the package cache. Can be a list of vectors, which will be interpreted as files with subdirs.


pkgfilecache documentation built on Sept. 1, 2026, 1:08 a.m.