make_pgk_cache_subdir_for_relative_file: Given a relative file, create the subdir in the package cache...

View source: R/filecache.R

make_pgk_cache_subdir_for_relative_fileR Documentation

Given a relative file, create the subdir in the package cache if needed.

Description

Given a relative file, create the subdir in the package cache if needed.

Usage

make_pgk_cache_subdir_for_relative_file(pkg_info, relative_file)

Arguments

pkg_info

named list. Package identifier, see get_pkg_info() on how to get one.

relative_file

string or vector of strings. If a string, this function does nothing. If a vector of strings, a path is created from the elements using file.path, and the directory of it (determined by dirname()) is created.


pkgfilecache documentation built on Sept. 1, 2026, 1:08 a.m.