manifest_cli_usage: Get the usage message of the manifest generation CLI.

View source: R/cli.R

manifest_cli_usageR Documentation

Get the usage message of the manifest generation CLI.

Description

Internal helper that returns the usage text printed by manifest_cli for --help and on errors.

Usage

manifest_cli_usage()

Value

character vector with the usage text, one element per line.


pkgfilecache documentation built on Sept. 1, 2026, 1:08 a.m.