pkg_cache_dir_with_version: Append the optional package version to a cache directory...

View source: R/filecache.R

pkg_cache_dir_with_versionR Documentation

Append the optional package version to a cache directory path.

Description

Append the optional package version to a cache directory path.

Usage

pkg_cache_dir_with_version(dir, pkg_info)

Arguments

dir

string. The cache directory path (already including the package name).

pkg_info

named list. Package identifier, see get_pkg_info() on how to get one.

Value

string. The directory path, with the version appended if the package info contains one.


pkgfilecache documentation built on Sept. 1, 2026, 1:08 a.m.