| manifest_cli_usage | R Documentation |
Internal helper that returns the usage text printed by manifest_cli for --help and on errors.
manifest_cli_usage()
character vector with the usage text, one element per line.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.