| manifest_script | R Documentation |
Return the full path to the make_manifest.R script that ships with the package (installed into the package's exec subdirectory). This script is a thin wrapper around manifest_cli and can be run with Rscript to generate a manifest from the command line. On Unix-like systems you can also copy it to a directory on your PATH and make it executable with chmod +x, then run it like a normal command.
manifest_script()
character string. The full path to the script, or "" if the script cannot be found (e.g., because the package is not installed correctly).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.