| pkg_cache_dir_with_version | R Documentation |
Append the optional package version to a cache directory path.
pkg_cache_dir_with_version(dir, pkg_info)
dir |
string. The cache directory path (already including the package name). |
pkg_info |
named list. Package identifier, see get_pkg_info() on how to get one. |
string. The directory path, with the version appended if the package info contains one.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.