| write_manifest_from_dir | R Documentation |
Create a manifest (CSV file) that describes all files in the given directory. This is meant to remove the tedious manual work of adding many files to a package: put the files into a directory (subdirectories are preserved), run this function once, and a ready-to-use manifest is written. The MD5 checksum of every file is computed automatically.
write_manifest_from_dir(dir, out, url_base = NULL)
dir |
string. The directory containing the local files to describe. Files in subdirectories are included, and their relative paths (using '/' as separator) become the |
out |
string. The path of the CSV file to write the manifest to. Typically something like |
url_base |
string or NULL. If given, the |
The generated manifest as a data.frame, invisibly.
## Not run:
manifest = write_manifest_from_dir("~/mydata", "inst/extdata/files.csv",
url_base = "https://example.com/data/")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.